/* size and align the headers on the home screen */
.home-header {
  font-size: 1.6em;
  margin-bottom: 10px;
}
.home-header, .home-header a {
  color: #da223a;
  text-decoration: none;
}
.home-header i {
  vertical-align: middle;
  padding-right: 8px;
}
.home-header span { vertical-align: middle; }

/* home grid layout */
.home-container {
  display: flex;
  flex-wrap: wrap;
}

.home-box {
  flex-basis: calc(33.33% - 30px);
  margin: 10px;
  min-width: 200px;
  min-height: 200px;

  box-sizing: border-box;
  padding: 19px;
  background-color: #f5f5f5;
  border: 1px solid #e3e3e3;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.05);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.05);
}


/* Setting admonition */
:root {
    --md-admonition-icon--setting: url('data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA1MTIgNTEyIj48IS0tIEZvbnQgQXdlc29tZSBGcmVlIDUuMTUuNCBieSBAZm9udGF3ZXNvbWUgLSBodHRwczovL2ZvbnRhd2Vzb21lLmNvbSBMaWNlbnNlIC0gaHR0cHM6Ly9mb250YXdlc29tZS5jb20vbGljZW5zZS9mcmVlIChJY29uczogQ0MgQlkgNC4wLCBGb250czogU0lMIE9GTCAxLjEsIENvZGU6IE1JVCBMaWNlbnNlKSAtLT48cGF0aCBkPSJNNDg3LjQgMzE1LjdsLTQyLjYtMjQuNmM0LjMtMjMuMiA0LjMtNDcgMC03MC4ybDQyLjYtMjQuNmM0LjktMi44IDcuMS04LjYgNS41LTE0LTExLjEtMzUuNi0zMC02Ny44LTU0LjctOTQuNi0zLjgtNC4xLTEwLTUuMS0xNC44LTIuM0wzODAuOCAxMTBjLTE3LjktMTUuNC0zOC41LTI3LjMtNjAuOC0zNS4xVjI1LjhjMC01LjYtMy45LTEwLjUtOS40LTExLjctMzYuNy04LjItNzQuMy03LjgtMTA5LjIgMC01LjUgMS4yLTkuNCA2LjEtOS40IDExLjdWNzVjLTIyLjIgNy45LTQyLjggMTkuOC02MC44IDM1LjFMODguNyA4NS41Yy00LjktMi44LTExLTEuOS0xNC44IDIuMy0yNC43IDI2LjctNDMuNiA1OC45LTU0LjcgOTQuNi0xLjcgNS40LjYgMTEuMiA1LjUgMTRMNjcuMyAyMjFjLTQuMyAyMy4yLTQuMyA0NyAwIDcwLjJsLTQyLjYgMjQuNmMtNC45IDIuOC03LjEgOC42LTUuNSAxNCAxMS4xIDM1LjYgMzAgNjcuOCA1NC43IDk0LjYgMy44IDQuMSAxMCA1LjEgMTQuOCAyLjNsNDIuNi0yNC42YzE3LjkgMTUuNCAzOC41IDI3LjMgNjAuOCAzNS4xdjQ5LjJjMCA1LjYgMy45IDEwLjUgOS40IDExLjcgMzYuNyA4LjIgNzQuMyA3LjggMTA5LjIgMCA1LjUtMS4yIDkuNC02LjEgOS40LTExLjd2LTQ5LjJjMjIuMi03LjkgNDIuOC0xOS44IDYwLjgtMzUuMWw0Mi42IDI0LjZjNC45IDIuOCAxMSAxLjkgMTQuOC0yLjMgMjQuNy0yNi43IDQzLjYtNTguOSA1NC43LTk0LjYgMS41LTUuNS0uNy0xMS4zLTUuNi0xNC4xek0yNTYgMzM2Yy00NC4xIDAtODAtMzUuOS04MC04MHMzNS45LTgwIDgwLTgwIDgwIDM1LjkgODAgODAtMzUuOSA4MC04MCA4MHoiLz48L3N2Zz4=')
}

.md-typeset .admonition.setting,
.md-typeset details.setting {
    border-color: rgb(43, 155, 70);
}
.md-typeset .setting > .admonition-title,
.md-typeset .setting > summary {
    background-color: rgba(43, 155, 70, 0.1);
    border-color: rgb(43, 155, 70);
}
.md-typeset .setting > .admonition-title::before,
.md-typeset .setting > summary::before {
    background-color: rgb(43, 155, 70);
    -webkit-mask-image: var(--md-admonition-icon--setting);
    mask-image: var(--md-admonition-icon--setting);
}

.md-nav__link {
  padding-top: 0.4em;
}

.md-ellipsis {
  padding-top: 0.4em;
}

.url-edit-link > svg {
    float: right;
    height: 1rem;
    width: 1rem;
    /*line-height: 1em;*/
    fill: rgb(43, 155, 70);
    cursor: pointer;
}
.url-edit-link > svg:hover {
    fill: rgb(37, 133, 59);
}
.setting-link {
    /*font-size: 1.1em;*/
    /*line-height: 1em;*/
    cursor: pointer;
}
a.setting-link, a.setting-link:visited {
    color: var(--md-admonition-fg-color);
}

a.setting-link:focus, a.setting-link:hover {
    color: rgb(37, 133, 59);
}

.md-typeset .admonition, .md-typeset details {
    font-size: 1em;
}
